==> mariadb-connector-cpp-0.9.2-beta-src.tar.gz: mariadb-connector-cpp-0.9.2-beta-src/test/CJUnitTestsPort/resources.h <==
/*
 * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0, as
 * published by the Free Software Foundation.
 *
 * This program is also distributed with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms,
 * as designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an
 * additional permission to link the program and your derivative works
 * with the separately licensed software that they have included with
 * MySQL.
 *
 * Without limiting anything contained in the foregoing, this file,
 * which is part of MySQL Connector/C++, is also subject to the
 * Universal FOSS Exception, version 1.0, a copy of which can be found at
 * http://oss.oracle.com/licenses/universal-foss-exception.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */



#ifndef _TESTSUITE_RESOURCES_H_
#define _TESTSUITE_RESOURCES_H_

#include "../common/ccppTypes.h"

namespace testsuite
{
namespace resources
{

class CharsetMapping
{
public:

  typedef std::map<String, unsigned int> Map;
  typedef Map::const_iterator cit;

private:

  /* Hiding constructor */
  CharsetMapping()
  {
    Init();
  }

  Map STATIC_CHARSET_TO_NUM_BYTES_MAP;

  void Init();

public:

  static const CharsetMapping & Instance();

  const Map & GetMap() const
  {
    return STATIC_CHARSET_TO_NUM_BYTES_MAP;
  }
};

int LoadProperties(const String & fileName, Properties &props
                   , const char * _possibleLocations[]=NULL);
}
}
#endif

==> mariadb-connector-cpp-1.1.1-beta-src.tar.gz: mariadb-connector-cpp-1.1.1-beta-src/test/CJUnitTestsPort/resources.h <==
/*
 * Copyright (c) 2008, 2018, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0, as
 * published by the Free Software Foundation.
 *
 * This program is also distributed with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms,
 * as designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an
 * additional permission to link the program and your derivative works
 * with the separately licensed software that they have included with
 * MySQL.
 *
 * Without limiting anything contained in the foregoing, this file,
 * which is part of MySQL Connector/C++, is also subject to the
 * Universal FOSS Exception, version 1.0, a copy of which can be found at
 * http://oss.oracle.com/licenses/universal-foss-exception.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */



#ifndef _TESTSUITE_RESOURCES_H_
#define _TESTSUITE_RESOURCES_H_

#include "../common/ccppTypes.h"

namespace testsuite
{
namespace resources
{

class CharsetMapping
{
public:

  typedef std::map<String, unsigned int> Map;
  typedef Map::const_iterator cit;

private:

  /* Hiding constructor */
  CharsetMapping()
  {
    Init();
  }

  Map STATIC_CHARSET_TO_NUM_BYTES_MAP;

  void Init();

public:

  static const CharsetMapping & Instance();

  const Map & GetMap() const
  {
    return STATIC_CHARSET_TO_NUM_BYTES_MAP;
  }
};

int LoadProperties(const String & fileName, TestProperties &props
                   , const char * _possibleLocations[]=NULL);
}
}
#endif
